From ed30c60150ffda0301eb1f8d30c93cac94de41df Mon Sep 17 00:00:00 2001
From: tbrehm <t.brehm@ispconfig.org>
Date: Mon, 25 Jul 2011 10:38:22 -0400
Subject: [PATCH] Fixed some warnings in the installer.

---
 interface/web/dns/dns_a_list.php |    7 ++-----
 1 files changed, 2 insertions(+), 5 deletions(-)

diff --git a/interface/web/dns/dns_a_list.php b/interface/web/dns/dns_a_list.php
index 6899b3a..c01aec6 100644
--- a/interface/web/dns/dns_a_list.php
+++ b/interface/web/dns/dns_a_list.php
@@ -12,11 +12,8 @@
 * End Form configuration
 ******************************************/
 
-// Checking module permissions
-if(!stristr($_SESSION["s"]["user"]["modules"],'dns')) {
-	header("Location: ../index.php");
-	exit;
-}
+//* Check permissions for module
+$app->auth->check_module_permissions('dns');
 
 $app->uses('listform_actions');
 $app->listform_actions->SQLExtWhere = "type = 'A'";

--
Gitblit v1.9.1